/*Allows you to translate and scale an image by adjusting the origin and spacing.*/

#include "vtkTransformImage.h"
#include "vtkInformation.h"
#include "vtkInformationVector.h"
#include "vtkObjectFactory.h"
#include "vtkImageAlgorithm.h"
#include "vtkImageData.h"
#include "vtkPointData.h"
#include "vtkCellData.h"

vtkCxxRevisionMacro(vtkTransformImage, "$Revision: 1259 $");
vtkStandardNewMacro(vtkTransformImage);

vtkTransformImage::vtkTransformImage()
{
  this->SetNumberOfInputPorts(1);
  this->SetNumberOfOutputPorts(1);
}

vtkTransformImage::~vtkTransformImage()
{
}


int vtkTransformImage::RequestData(vtkInformation *request,
                                   vtkInformationVector **inputVector,
                                   vtkInformationVector *outputVector)
{
  vtkImageData *input = vtkImageData::GetData(inputVector[0]);
  vtkImageData *output = vtkImageData::GetData(outputVector);

  output->CopyStructure(input);
  output->GetPointData()->PassData(input->GetPointData());
  output->GetCellData()->PassData(input->GetCellData());

  double origin[3], spacing[3];
  output->GetOrigin(origin);
  output->GetSpacing(spacing);

  for (int i = 0; i < 3; i++)
    {
    origin[i] += this->Translate[i];
    spacing[i] *= this->Scale[i];
    }

  output->SetOrigin(origin);
  output->SetSpacing(spacing);

  return 1;
}


void vtkTransformImage::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}

